@@ -105,6 +105,7 @@
                            'Accton::ES3528M' => 'Accton ES3528M',
                            'Amer::SS2R24i' => 'Amer SS2R24i',
                            'Aruba::Controller_200' => 'Aruba Controller 200', 
+                           'Avaya' => 'Avaya (see Nortel)', 
                            'Cisco::Aironet_1130' => 'Cisco Aironet 1130',
                            'Cisco::Aironet_1242' => 'Cisco Aironet 1242',
                            'Cisco::Aironet_1250' => 'Cisco Aironet 1250',
@@ -143,11 +144,13 @@
                            'Meru::MC3000' => 'Meru MC3000',
                            'Nortel::BayStack4550' => 'Nortel BayStack 4550',
                            'Nortel::BayStack470' => 'Nortel BayStack 470',
-                           'Nortel::BayStack5520' => 'Nortel BayStack 5520',
-                           'Nortel::BayStack5520Stacked' => 'Nortel BayStack 5520 Stacked',
+                           'Nortel::BayStack5500' => 'Nortel BayStack 5500 Series',
+                           'Nortel::BayStack5500_6x' => 'Nortel BayStack 5500 w/ firmware 6.x',
                            'Nortel::BPS2000' => 'Nortel BPS 2000',
                            'Nortel::ERS2500' => 'Nortel ERS 2500 Series',
                            'Nortel::ERS4500' => 'Nortel ERS 4500 Series',
+                           'Nortel::ERS5500' => 'Nortel ERS 5500 Series',
+                           'Nortel::ERS5500_6x' => 'Nortel ERS 5500 w/ firmware 6.x',
                            'Nortel::ES325' => 'Nortel ES325',
                            'PacketFence' => 'PacketFence',
                            'SMC::TS6128L2' => 'SMC TigerStack 6128L2',
