@@ -11,6 +11,22 @@ to access SNMP enabled Aruba switches.
 
 =cut
 
+=head1 BUGS AND LIMITATIONS
+
+=over
+
+=item The module currently doesn't work with Controllers in the MASTER / LOCAL configuration
+
+This is caused by the fact that the client state is on the LOCAL controller but for PacketFence the IP who initiated the RADIUS authentication is the IP it talks to (which is the master and not the local).
+
+=item Telnet deauthentication
+
+Wireless deauthentication (deassociation) works only in Telnet
+
+=back 
+
+=cut
+
 use strict;
 use warnings;
 use diagnostics;
@@ -21,8 +37,6 @@ use Log::Log4perl;
 use Net::Telnet;
 use pf::util;
 
-use constant AUTH_DOT1X => 4;
-
 =head1 SUBROUTINES
 
 TODO: this list is incomplete
@@ -60,7 +74,6 @@ sub parseTrap {
 
     if ( $trapString =~ /\.1\.3\.6\.1\.4\.1\.14823\.2\.3\.1\.11\.1\.2\.1017[|].+[|]\.1\.3\.6\.1\.4\.1\.14823\.2\.3\.1\.11\.1\.1\.52\.[0-9]+ = Hex-STRING: ([0-9A-Z]{2} [0-9A-Z]{2} [0-9A-Z]{2} [0-9A-Z]{2} [0-9A-Z]{2} [0-9A-Z]{2})/ ) {   
         $trapHashRef->{'trapType'}    = 'dot11Deauthentication';
-        $trapHashRef->{'trapIfIndex'} = "WIFI";
         $trapHashRef->{'trapMac'}     = lc($1);
         $trapHashRef->{'trapMac'} =~ s/ /:/g;
     
@@ -77,9 +90,8 @@ Here, we find out what submodule to call _dot1xDeauthenticateMAC or _deauthentic
 
 =cut
 sub deauthenticateMac {
-    my ( $this, $mac ) = @_;
+    my ( $this, $mac, $is_dot1x ) = @_;
     my $logger = Log::Log4perl::get_logger( ref($this) );
-    my $OID_nUserAuthenticationMethod = '1.3.6.1.4.1.14823.2.2.1.4.1.2.1.6'; # from WLSX-USER-MIB
 
     if ( !$this->isProductionMode() ) {
         $logger->info("not in production mode ... we won't write to the bnsMobileStationTable");
@@ -96,41 +108,58 @@ sub deauthenticateMac {
         return 1;
     }
 
-    # Query the controller to get the type of authentication the user is using
-    $logger->trace("SNMP get_table for nUserAuthenticationMethod: $OID_nUserAuthenticationMethod");
-    my $result = $this->{_sessionRead}->get_table(-baseoid => "$OID_nUserAuthenticationMethod");
-    # is there at least one result?
-    if (keys %{$result}) {
-
-        # convert MAC into oid format
-        my $macOID = mac2oid($mac);
-
-        # Fetch Auth Method for the MAC we are interested in
-        my $count = 0;
-        foreach my $macIpToUserAuthMethod (keys %{$result}) {
-            if ($macIpToUserAuthMethod =~ /^$OID_nUserAuthenticationMethod\.$macOID/) {
-                if ($count > 1) { 
-                    $logger->warn("MAC: $mac returned two authentication method, it should not happen!" .
-                                  " Please file a bug with steps to reproduce");
-                    return;
-                } else {
-                    if ($result->{$macIpToUserAuthMethod} == AUTH_DOT1X) {
-                        $logger->trace("using 802.1x deauth method");
-                        $this->_dot1xDeauthenticateMAC($mac);
-                    } else {
-                        # Any other authentication method lets kick out with traditionnal approach
-                        $logger->trace("using non-802.1x deauth method");
-                        $this->_deauthenticateMAC($mac);
-                    }
-                    $count++;
-                }
-           }
-        }
+    if (defined($is_dot1x) && $is_dot1x) {
+        $logger->debug("deauthenticate $mac using 802.1x deauth method");
+        $this->_dot1xDeauthenticateMAC($mac);
     } else {
-        $logger->error("was not able to find user authentication type for mac $mac, unable to deauthenticate");
+        # Any other authentication method lets kick out with traditionnal approach
+        $logger->debug("deauthenticate $mac using non-802.1x deauth method");
+        $this->_deauthenticateMAC($mac);
     }
 }
 
+# old code used to find user authentication method then kick him out accordingly, not required anymore
+#use constant AUTH_DOT1X => 4;
+#sub deauthenticateMac {
+#    my ($this, $mac) = @_;
+#    my $logger = Log::Log4perl::get_logger( ref($this) );
+#    my $OID_nUserAuthenticationMethod = '1.3.6.1.4.1.14823.2.2.1.4.1.2.1.6'; # from WLSX-USER-MIB
+#    ...
+#    # Query the controller to get the type of authentication the user is using
+#    $logger->trace("SNMP get_table for nUserAuthenticationMethod: $OID_nUserAuthenticationMethod");
+#    my $result = $this->{_sessionRead}->get_table(-baseoid => "$OID_nUserAuthenticationMethod");
+#    # is there at least one result?
+#    if (keys %{$result}) {
+#
+#        # convert MAC into oid format
+#        my $macOID = mac2oid($mac);
+#
+#        # Fetch Auth Method for the MAC we are interested in
+#        my $count = 0;
+#        foreach my $macIpToUserAuthMethod (keys %{$result}) {
+#            if ($macIpToUserAuthMethod =~ /^$OID_nUserAuthenticationMethod\.$macOID/) {
+#                if ($count > 1) {
+#                    $logger->warn("MAC: $mac returned two authentication method, it should not happen!" .
+#                                  " Please file a bug with steps to reproduce");
+#                    return;
+#                } else {
+#                    if ($result->{$macIpToUserAuthMethod} == AUTH_DOT1X) {
+#                        $logger->trace("using 802.1x deauth method");
+#                        $this->_dot1xDeauthenticateMAC($mac);
+#                    } else {
+#                        # Any other authentication method lets kick out with traditionnal approach
+#                        $logger->trace("using non-802.1x deauth method");
+#                        $this->_deauthenticateMAC($mac);
+#                    }
+#                    $count++;
+#                }
+#           }
+#        }  
+#    } else {
+#        $logger->error("was not able to find user authentication type for mac $mac, unable to deauthenticate");
+#    }
+#}
+
 =item _dot1xDeauthenticateMAC - deauthenticate a MAC from controller when user is in 802.1x mode
 
 * Private: don't call outside of same object, use deauthenticateMac externally *
@@ -148,7 +177,7 @@ sub _dot1xDeauthenticateMAC {
 
     my $cmd = "aaa user delete mac $mac";
 
-    $logger->debug("deauthenticating 802.1x $mac with `$cmd`");
+    $logger->info("deauthenticating 802.1x $mac with `$cmd`");
     $session->cmd($cmd);
 
     $session->close();
@@ -198,7 +227,7 @@ sub _deauthenticateMAC {
                     my $apSSID = uc("$1:$2:$3:$4:$5:$6");
                     my $cmd = "stm kick-off-sta $mac $apSSID";
 
-                    $logger->debug("deauthenticating $mac from SSID $apSSID with `$cmd`");
+                    $logger->info("deauthenticating $mac from SSID $apSSID with `$cmd`");
                     $session->cmd($cmd);
                     $count++;
                 } else {
@@ -252,6 +281,30 @@ sub getTelnetSession {
     return $session;
 }
 
+=item extractSsid
+
+Find RADIUS SSID parameter out of RADIUS REQUEST parameters
+
+Aruba specific parser. See pf::SNMP for base implementation.
+
+=cut
+sub extractSsid {
+    my ($this, $radius_request) = @_;
+    my $logger = Log::Log4perl::get_logger(ref($this));
+
+    # Aruba-Essid-Name VSA
+    if (defined($radius_request->{'Aruba-Essid-Name'})) {
+        return $radius_request->{'Aruba-Essid-Name'};
+    }
+
+    $logger->warn(
+        "Unable to extract SSID for module " . ref($this) . ". SSID-based VLAN assignments won't work. "
+        . "Please let us know so we can add support for it."
+    );
+    return;
+}
+
+
 =back
 
 =head1 AUTHOR
@@ -262,7 +315,7 @@ Olivier Bilodeau <obilodeau@inverse.ca>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2009 Inverse inc.
+Copyright (C) 2009,2010 Inverse inc.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
