@@ -27,10 +27,12 @@ use pf::node;
 use pf::SNMP;
 use pf::SwitchFactory;
 use pf::util;
-use pf::vlan::custom;
+use pf::vlan::custom $VLAN_API_LEVEL;
 # constants used by this module are provided by
 use pf::radius::constants;
 
+our $VERSION = 1.00;
+
 =head1 SUBROUTINES
 
 =over
@@ -176,6 +178,17 @@ sub authorize {
         $isPhone ? VOIP : NO_VOIP, $connection_type, $user_name, $ssid
     );
 
+    # does the switch support Dynamic VLAN Assignment
+    if (!$switch->supportsRadiusDynamicVlanAssignment()) {
+        $logger->info(
+            "Switch doesn't support Dynamic VLAN assignment. " . 
+            "Setting VLAN with SNMP on " . $switch->{_ip} . " ifIndex $port to $vlan"
+        );
+        # WARNING: passing empty switch-lock for now
+        # When the _setVlan of a switch who can't do RADIUS VLAN assignment uses the lock we will need to re-evaluate
+        $switch->_setVlan( $port, $vlan, undef, {} );
+    }
+
     # cleanup
     $switch->disconnectRead();
     $switch->disconnectWrite();
@@ -352,7 +365,7 @@ sub _authorizeVoip {
     my ($this, $connection_type, $switch, $mac, $port, $user_name, $ssid) = @_;
     my $logger = Log::Log4perl::get_logger(ref($this));
 
-    if (!$switch->supportsRadiusVoip) {
+    if (!$switch->supportsRadiusVoip()) {
         $logger->warn("Returning failure to RADIUS.");
         $switch->disconnectRead();
         $switch->disconnectWrite();
