@@ -552,7 +552,7 @@ sub createpid {
     my $logger = Log::Log4perl::get_logger('pf::util');
     $pname = basename($0) if ( !$pname );
     my $pid     = $$;
-    my $pidfile = $install_dir . "/var/$pname.pid";
+    my $pidfile = $var_dir . "/run/$pname.pid";
     $logger->info("$pname starting and writing $pid to $pidfile");
     my $outfile = new FileHandle ">$pidfile";
     if ( defined($outfile) ) {
@@ -569,7 +569,7 @@ sub readpid {
     my ($pname) = @_;
     my $logger = Log::Log4perl::get_logger('pf::util');
     $pname = basename($0) if ( !$pname );
-    my $pidfile = $install_dir . "/var/$pname.pid";
+    my $pidfile = $var_dir . "/run/$pname.pid";
     my $file    = new FileHandle "$pidfile";
     if ( defined($file) ) {
         my $pid = $file->getline();
@@ -585,7 +585,7 @@ sub readpid {
 sub deletepid {
     my ($pname) = @_;
     $pname = basename($0) if ( !$pname );
-    my $pidfile = $install_dir . "/var/$pname.pid";
+    my $pidfile = $var_dir . "/run/$pname.pid";
     unlink($pidfile) || return (-1);
     return (1);
 }
@@ -786,7 +786,7 @@ sub str_to_connection_type {
     } elsif (defined($conn_type_str) && $conn_type_str eq '') {
 
         $logger->debug("got an empty connection_type, this happens if we discovered the node but it never connected");
-        return 'Unknown';
+        return UNKNOWN;
 
     } else {
         my ($package, undef, undef, $routine) = caller(1);
@@ -811,7 +811,7 @@ Copyright (C) 2005 David LaPorte
 
 Copyright (C) 2005 Kevin Amorin
 
-Copyright (C) 2009,2010 Inverse inc.
+Copyright (C) 2009-2011 Inverse inc.
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
