@@ -16,13 +16,16 @@ use warnings;
 use diagnostics;
 
 use Log::Log4perl;
+use threads;
+use threads::shared;
+
 use pf::config;
 use pf::node qw(node_view node_add_simple node_exist);
 use pf::SNMP::constants;
 use pf::util;
 use pf::violation qw(violation_count_trap violation_exist_open violation_view_top);
-use threads;
-use threads::shared;
+
+our $VERSION = 1.00;
 
 =head1 SUBROUTINES
 
@@ -106,7 +109,7 @@ sub doWeActOnThisTrap {
     if ( ( $ifType == $SNMP::ETHERNET_CSMACD ) || ( $ifType == $SNMP::GIGABIT_ETHERNET ) ) {
         my @upLinks = $switch->getUpLinks();
         # TODO: need to validate for empty array here to avoid warning
-        if ( $upLinks[0] == -1 ) {
+        if ( @upLinks && $upLinks[0] == -1 ) {
             $logger->warn("Can't determine Uplinks for the switch -> do nothing");
         } else {
             if ( grep( { $_ == $ifIndex } @upLinks ) == 0 ) {
