@@ -27,6 +27,7 @@ use strict;
 use warnings;
 use Date::Parse;
 use File::Basename;
+use JSON;
 use POSIX;
 use Template;
 use Locale::gettext;
@@ -111,14 +112,6 @@ var action = function()
 }
 EOT
     }
-    if ( -r "$conf_dir/templates/release.pl" ) {
-        my $include_fh;
-        open $include_fh, '<', "$conf_dir/templates/release.pl";
-        while (<$include_fh>) {
-            eval $_;
-        }
-        close $include_fh;
-    }
     my $html_txt;
     my $template = Template->new(
         { INCLUDE_PATH => ["$install_dir/html/user/content/templates"], } );
@@ -210,14 +203,7 @@ sub generate_login_page {
 
     my $cookie = $cgi->cookie( CGISESSID => $session->id );
     print $cgi->header( -cookie => $cookie );
-    if ( -r "$conf_dir/templates/login.pl" ) {
-        my $include_fh;
-        open $include_fh, '<', "$conf_dir/templates/login.pl";
-        while (<$include_fh>) {
-            eval $_;
-        }
-        close $include_fh;
-    }
+
     my $template = Template->new(
         { INCLUDE_PATH => ["$install_dir/html/user/content/templates"], } );
     $template->process( "login.html", $vars );
@@ -239,14 +225,7 @@ sub generate_enabler_page {
 
     my $cookie = $cgi->cookie( CGISESSID => $session->id );
     print $cgi->header( -cookie => $cookie );
-    if ( -r "$conf_dir/templates/enabler.pl" ) {
-        my $include_fh;
-        open $include_fh, '<', "$conf_dir/templates/enabler.pl";
-        while (<$include_fh>) {
-            eval $_;
-        }
-        close $include_fh;
-    }
+
     my $template = Template->new(
         { INCLUDE_PATH => ["$install_dir/html/user/content/templates"], } );
     $template->process( "enabler.html", $vars );
@@ -266,14 +245,7 @@ sub generate_redirect_page {
 
     my $cookie = $cgi->cookie( CGISESSID => $session->id );
     print $cgi->header( -cookie => $cookie );
-    if ( -r "$conf_dir/templates/redirect.pl" ) {
-        my $include_fh;
-        open $include_fh, '<', "$conf_dir/templates/redirect.pl";
-        while (<$include_fh>) {
-            eval $_;
-        }
-        close $include_fh;
-    }
+
     my $template = Template->new(
         { INCLUDE_PATH => ["$install_dir/html/user/content/templates"], } );
     $template->process( "redirect.html", $vars );
@@ -307,14 +279,7 @@ sub generate_scan_status_page {
 
     my $cookie = $cgi->cookie( CGISESSID => $session->id );
     print $cgi->header( -cookie => $cookie );
-    if ( -r "$conf_dir/templates/scan-in-progress.pl" ) {
-        my $include_fh;
-        open $include_fh, '<', "$conf_dir/templates/scan-in-progress.pl";
-        while (<$include_fh>) {
-            eval $_;
-        }
-        close $include_fh;
-    }
+
     my $template = Template->new(
         { INCLUDE_PATH => ["$install_dir/html/user/content/templates"], } );
     $template->process( "scan-in-progress.html", $vars );
@@ -353,14 +318,7 @@ sub generate_error_page {
 
     my $cookie = $cgi->cookie( CGISESSID => $session->id );
     print $cgi->header( -cookie => $cookie );
-    if ( -r "$conf_dir/templates/error.pl" ) {
-        my $include_fh;
-        open $include_fh, '<', "$conf_dir/templates/error.pl";
-        while (<$include_fh>) {
-            eval $_;
-        }
-        close $include_fh;
-    }
+
     my $template = Template->new(
         { INCLUDE_PATH => ["$install_dir/html/user/content/templates"], } );
     $template->process( "error.html", $vars );
@@ -427,15 +385,6 @@ sub generate_status_page {
             };
     }
 
-    if ( -r "$conf_dir/templates/status.pl" ) {
-        my $include_fh;
-        open $include_fh, '<', "$conf_dir/templates/status.pl";
-        while (<$include_fh>) {
-            eval $_;
-        }
-        close $include_fh;
-    }
-
     my $cookie = $cgi->cookie( CGISESSID => $session->id );
     print $cgi->header( -cookie => $cookie );
     my $template = Template->new(
@@ -444,6 +393,30 @@ sub generate_status_page {
     exit;
 }
 
+=item generate_status_json
+
+Gives information about current node in JSON format
+
+=cut
+sub generate_status_json {
+    my ( $cgi, $session, $mac ) = @_;
+
+    my $node_info = node_view($mac);
+    my $ip = pf::web::get_client_ip($cgi);
+
+    print $cgi->header( 'application/json' );
+    print objToJson({
+        'mac' => $mac,
+        'ip' => $ip,
+        'hostname' => $node_info->{'computername'},
+        'status' => $node_info->{'status'},
+        'pid' => $node_info->{'pid'},
+        'nbopenviolations' => $node_info->{'nbopenviolations'}
+    });
+
+    exit;
+}
+
 =item web_node_register
 
 This sub is meant to be redefined by pf::web::custom to fit your specific needs.
@@ -494,6 +467,8 @@ sub web_node_record_user_agent {
             ." (".$user_agent_info[0]->{'useragent'}.") trigger"
         );
         require pf::violation;
+        # TODO we should also trigger the broader class (ex: 101 and 1 for a useragent id 101 which is part of class 1)
+        # issue #1192
         pf::violation::violation_trigger( $mac, $user_agent_info[0]->{'useragent_id'}, "USERAGENT" );
 
     } else {
@@ -633,16 +608,6 @@ sub generate_registration_page {
         }
     }
 
-    if ( -r "$conf_dir/templates/register.pl" ) {
-        my $include_fh;
-        open $include_fh, '<', "$conf_dir/templates/register.pl";
-        while (<$include_fh>) {
-            eval $_;
-        }
-        close $include_fh;
-    }
-    #my $cookie = $cgi->cookie( CGISESSID => $session->id );
-    #print $cgi->header( -cookie => $cookie );
     my $template = Template->new(
         { INCLUDE_PATH => ["$install_dir/html/user/content/templates"], } );
     $template->process( "register.html", $vars );
@@ -669,6 +634,10 @@ sub generate_pending_page {
             { name => gettext('IP'),  value => $ip },
             { name => gettext('MAC'), value => $mac }
         ],
+        destination_url => $destination_url,
+        initial_delay => $CAPTIVE_PORTAL{'NET_DETECT_INITIAL_DELAY'},
+        retry_delay => $CAPTIVE_PORTAL{'NET_DETECT_RETRY_DELAY'},
+        external_ip => $Config{'captive_portal'}{'network_detection_ip'},
     };
 
     my $cookie = $cgi->cookie( CGISESSID => $session->id );
